# 🔗 YGoogleDrive

💱 Google Drive'ın verdiği ön izleme bağlantılarını indilirebilir bağlantıya dönüştürür

## 🎌 Kullanım Notları

- 🔄 Google Drive bağlantılarını dönüştürmek için `ygoogledrive` komutu kullanılır
- 👁️ Ön izleme bağlantılarını direkt indirme bağlantılarına çevirir
- 🆘 Kullanım detayları için `ygoogledrive -h` yazın


## 💖 Destek ve İletişim

​[​![Github](../.github/assets/github_32px.png)​](https://github.com/yedhrab) [​![LinkedIn](../.github/assets/linkedin_32px.png)​](https://www.linkedin.com/in/yemreak/) [​![Website](../.github/assets/geography_32px.png)​](https://yemreak.com/) [​![Mail](../.github/assets/gmail_32px.png)​](mailto:yemreak.com@gmail.com?subject=YGoogleDrive%20%7C%20GitHub)​

​[​![Patreon](../.github/assets/become_a_patron_32px.png)](https://www.patreon.com/yemreak/)

## 🔏 Lisans

**The** [**Apache 2.0 License**](https://choosealicense.com/licenses/apache-2.0/) **©️ Yunus Emre Ak**

![YEmreAk](../.github/assets/ysigniture-trans.png)

